@@ -26,7 +26,7 @@ extensions = [
 html_theme = "sphinx_rtd_theme"
 
 DOC_ROOT = Path(__file__).parent
-tutorial_root = DOC_ROOT / "tutorials"
+structured_tutorials_root = DOC_ROOT / "tutorials"
 
 templates_path = ["_templates"]
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
